/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package org.ow2.petals.tools.jmx.api;

import java.io.IOException;
import java.util.Hashtable;
import java.util.Set;

import javax.jbi.management.AdminServiceMBean;
import javax.management.MBeanServerConnection;
import javax.management.MalformedObjectNameException;
import javax.management.ObjectName;

import org.ow2.petals.tools.jmx.api.exception.AdminDoesNotExistException;
import org.ow2.petals.tools.jmx.api.exception.AdminServiceErrorException;
import org.ow2.petals.tools.jmx.api.exception.PerformActionErrorException;

/**
 * Client API of the JMX Admin service.
 * 
 * @author rnaudin - EBM Websourcing
 * 
 */
public class AdminServiceClient extends PetalsAbstractServiceClient {

    /**
     * Action : get System Info
     */
    protected static final String SYSTEM_INFO = "getSystemInfo";

    private final static String ADMIN_SERVICE_JMX_NAME = "Admin";

    /**
     * Creates a new instance of {@link AdminServiceClient}
     * 
     * @param petalsDomain
     * @param beanServerConnection
     * @throws AdminDoesNotExistException
     * @throws AdminServiceErrorException
     */
    public AdminServiceClient(String petalsDomain, MBeanServerConnection beanServerConnection)
            throws AdminDoesNotExistException, AdminServiceErrorException {
        super(petalsDomain, beanServerConnection);

        try {
            Set<ObjectName> objNames;

            Hashtable<String, String> attributes = new Hashtable<String, String>();
            attributes.put(JMX_FIELD_NAME, ADMIN_SERVICE_JMX_NAME);
            attributes.put(JMX_FIELD_TYPE, JMX_SERVICE_TYPE);
            ObjectName objName = new ObjectName(petalsDomain, attributes);
            objNames = this.mBeanServerConnection.queryNames(objName, null);
            if (objNames != null && objNames.size() == 1) {
                this.mbeanName = objNames.iterator().next();
            } else {
                throw new AdminDoesNotExistException();
            }
        } catch (MalformedObjectNameException e) {
            throw new AdminServiceErrorException(e);
        } catch (IOException e) {
            throw new AdminServiceErrorException(e);
        }
    }

    /**
     * Get the version of the kernel of the PEtALS container
     * 
     * @see AdminServiceMBean#getSystemInfo()
     * @throws PerformActionErrorException
     */
    public String getSystemInfo() throws PerformActionErrorException {

        Object[] objectsLoad = new Object[0];
        String[] stringsLoad = new String[0];

        return (String) this.performAction(SYSTEM_INFO, objectsLoad, stringsLoad);
    }
}
