/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package org.ow2.petals.tools.jmx.api;

import java.io.IOException;
import java.util.Set;

import javax.management.MBeanServerConnection;
import javax.management.ObjectName;

import org.ow2.petals.tools.jmx.api.exception.PerformActionErrorException;
import org.ow2.petals.tools.jmx.api.exception.PetalsAdminDoesNotExistException;
import org.ow2.petals.tools.jmx.api.exception.PetalsAdminServiceErrorException;

import static org.ow2.petals.tools.jmx.api.IPetalsAdminService.MBean.PETALSADMIN_OBJECT_NAME;
import static org.ow2.petals.tools.jmx.api.IPetalsAdminService.OperationNames.SHUTDOWN;
import static org.ow2.petals.tools.jmx.api.IPetalsAdminService.OperationNames.STOP;

/**
 * Client API of the JMX Petals Admin service.
 * 
 * @author rnaudin - EBM Websourcing
 * 
 */
public class PetalsAdminServiceClient extends PetalsAbstractServiceClient implements
        IPetalsAdminService {

    /**
     * Creates a new instance of {@link PetalsAdminServiceClient}
     * 
     * @param petalsDomain
     * @param beanServerConnection
     * @throws PetalsAdminDoesNotExistException
     * @throws PetalsAdminServiceErrorException
     */
    public PetalsAdminServiceClient(String petalsDomain, MBeanServerConnection beanServerConnection)
            throws PetalsAdminDoesNotExistException, PetalsAdminServiceErrorException {
        super(petalsDomain, beanServerConnection);

        try {
            final Set<ObjectName> objNames = this.mBeanServerConnection.queryNames(
                    PETALSADMIN_OBJECT_NAME, null);
            if (objNames != null && objNames.size() == 1) {
                this.mbeanName = objNames.iterator().next();
            } else {
                throw new PetalsAdminDoesNotExistException();
            }
        } catch (IOException e) {
            throw new PetalsAdminServiceErrorException(e);
        }
    }

    /**
     * Stop the PEtALS container.
     * 
     * @see PetalsAdminServiceInterface#stopContainer()
     * @throws PerformActionErrorException
     */
    public String stopContainer() throws PerformActionErrorException {

        final Object[] objectsLoad = new Object[0];
        final String[] stringsLoad = new String[0];

        return (String) this.performAction(STOP, objectsLoad, stringsLoad);
    }

    /**
     * Shut down the PEtALS container.
     * 
     * @see PetalsAdminServiceInterface#shutdownContainer()
     * @throws PerformActionErrorException
     */
    public String shutdownContainer() throws PerformActionErrorException {

        final Object[] objectsLoad = new Object[0];
        final String[] stringsLoad = new String[0];

        return (String) this.performAction(SHUTDOWN, objectsLoad, stringsLoad);
    }
}
